==> seedsui-react-5.8.59.tgz: package/lib/Select/Main/index.js <==
var _excluded = ["visible", "value", "list", "multiple", "allowClear", "onSelect", "onBeforeChange", "onChange", "onSearch", "checkedType", "checkedPosition", "checkable", "headerRender", "footerRender", "listRender", "listHeaderRender", "listFooterRender", "listExtraHeaderRender", "listExtraFooterRender", "itemRender", "itemContentRender", "itemProps", "checkboxProps"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t.return && (u = t.return(), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useRef, useImperativeHandle, useState, Fragment } from 'react';
import { formatList } from "./../utils";
import NoData from "./../../NoData";
import List from "./List";

// Main
var Main = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var visible = _ref.visible,
    value = _ref.value,
    list = _ref.list,
    multiple = _ref.multiple,
    allowClear = _ref.allowClear,
    onSelect = _ref.onSelect,
    onBeforeChange = _ref.onBeforeChange,
    onChange = _ref.onChange,
    onSearch = _ref.onSearch,
    _ref$checkedType = _ref.checkedType,
    checkedType = _ref$checkedType === void 0 ? 'checkbox' : _ref$checkedType,
    _ref$checkedPosition = _ref.checkedPosition,
    checkedPosition = _ref$checkedPosition === void 0 ? 'right' : _ref$checkedPosition,
    checkable = _ref.checkable,
    headerRender = _ref.headerRender,
    footerRender = _ref.footerRender,
    listRender = _ref.listRender,
    listHeaderRender = _ref.listHeaderRender,
    listFooterRender = _ref.listFooterRender,
    listExtraHeaderRender = _ref.listExtraHeaderRender,
    listExtraFooterRender = _ref.listExtraFooterRender,
    itemRender = _ref.itemRender,
    itemContentRender = _ref.itemContentRender,
    itemProps = _ref.itemProps,
    checkboxProps = _ref.checkboxProps,
    props = _objectWithoutProperties(_ref, _excluded);
  // 搜索过滤
  var _useState = useState(''),
    _useState2 = _slicedToArray(_useState, 2),
    keyword = _useState2[0],
    setKeyword = _useState2[1];

  // 过滤非法数据
  // eslint-disable-next-line
  list = formatList(list, keyword, onSearch);

  // 节点
  var mainRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: mainRef.current,
      getRootDOM: function getRootDOM() {
        return mainRef.current;
      },
      search: search
    };
  });

  // 展开关键字
  function search(keyword) {
    setKeyword(keyword);
  }

  // 渲染头部
  var HeaderNode = null;
  if (typeof headerRender === 'function') {
    HeaderNode = headerRender({
      multiple: multiple,
      checkable: checkable,
      value: value,
      list: list,
      onChange: onChange
    });
  }
  // 渲染底部
  var FooterNode = null;
  if (typeof footerRender === 'function') {
    FooterNode = footerRender({
      multiple: multiple,
      checkable: checkable,
      value: value,
      list: list,
      onChange: onChange
    });
  }
  return /*#__PURE__*/React.createElement(React.Fragment, null, HeaderNode, /*#__PURE__*/React.createElement("div", _extends({}, props, {
    className: "picker-main".concat(props !== null && props !== void 0 && props.className ? ' ' + props.className : ''),
    ref: mainRef
  }), Object.isEmptyObject(list) && /*#__PURE__*/React.createElement(NoData, null), typeof listExtraHeaderRender === 'function' && listExtraHeaderRender({
    multiple: multiple,
    checkable: checkable,
    value: value,
    list: list,
    onChange: onChange
  }), /*#__PURE__*/React.createElement(List, {
    value: value,
    list: list,
    multiple: multiple,
    onBeforeChange: onBeforeChange,
    onChange: onChange
    // 选中效果: checkbox | tick | corner
    ,
    checkedType: checkedType
    // 选中位置: left | right
    ,
    checkedPosition: checkedPosition,
    checkable: checkable,
    itemProps: itemProps
  }), typeof listExtraFooterRender === 'function' && listExtraFooterRender({
    multiple: multiple,
    checkable: checkable,
    value: value,
    list: list,
    onChange: onChange
  })), FooterNode);
});
export default Main;

==> seedsui-react-5.8.79.tgz: package/lib/Select/Main/index.js <==
var _excluded = ["visible", "value", "list", "multiple", "allowClear", "onSelect", "onBeforeChange", "onChange", "onSearch", "checkedType", "checkedPosition", "checkable", "headerRender", "footerRender", "listRender", "listHeaderRender", "listFooterRender", "listExtraHeaderRender", "listExtraFooterRender", "itemRender", "itemContentRender", "itemProps", "checkboxProps"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t.return && (u = t.return(), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useRef, useImperativeHandle, useState } from 'react';
import { formatList } from "./../utils";
import NoData from "./../../NoData";
import List from "./List";

// Main
var Main = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var visible = _ref.visible,
    value = _ref.value,
    list = _ref.list,
    multiple = _ref.multiple,
    allowClear = _ref.allowClear,
    onSelect = _ref.onSelect,
    onBeforeChange = _ref.onBeforeChange,
    onChange = _ref.onChange,
    onSearch = _ref.onSearch,
    _ref$checkedType = _ref.checkedType,
    checkedType = _ref$checkedType === void 0 ? 'checkbox' : _ref$checkedType,
    _ref$checkedPosition = _ref.checkedPosition,
    checkedPosition = _ref$checkedPosition === void 0 ? 'right' : _ref$checkedPosition,
    checkable = _ref.checkable,
    headerRender = _ref.headerRender,
    footerRender = _ref.footerRender,
    listRender = _ref.listRender,
    listHeaderRender = _ref.listHeaderRender,
    listFooterRender = _ref.listFooterRender,
    listExtraHeaderRender = _ref.listExtraHeaderRender,
    listExtraFooterRender = _ref.listExtraFooterRender,
    itemRender = _ref.itemRender,
    itemContentRender = _ref.itemContentRender,
    itemProps = _ref.itemProps,
    checkboxProps = _ref.checkboxProps,
    props = _objectWithoutProperties(_ref, _excluded);
  // 搜索过滤
  var _useState = useState(''),
    _useState2 = _slicedToArray(_useState, 2),
    keyword = _useState2[0],
    setKeyword = _useState2[1];

  // 过滤非法数据
  // eslint-disable-next-line
  list = formatList(list, keyword, onSearch);

  // 节点
  var mainRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: mainRef.current,
      getRootDOM: function getRootDOM() {
        return mainRef.current;
      },
      search: search
    };
  });

  // 展开关键字
  function search(keyword) {
    setKeyword(keyword);
  }

  // 渲染头部
  var HeaderNode = null;
  if (typeof headerRender === 'function') {
    HeaderNode = headerRender({
      multiple: multiple,
      checkable: checkable,
      value: value,
      list: list,
      onChange: onChange
    });
  }
  // 渲染底部
  var FooterNode = null;
  if (typeof footerRender === 'function') {
    FooterNode = footerRender({
      multiple: multiple,
      checkable: checkable,
      value: value,
      list: list,
      onChange: onChange
    });
  }
  return /*#__PURE__*/React.createElement(React.Fragment, null, HeaderNode, /*#__PURE__*/React.createElement("div", _extends({}, props, {
    className: "picker-main".concat(props !== null && props !== void 0 && props.className ? ' ' + props.className : ''),
    ref: mainRef
  }), Object.isEmptyObject(list) && /*#__PURE__*/React.createElement(NoData, null), typeof listExtraHeaderRender === 'function' && listExtraHeaderRender({
    multiple: multiple,
    checkable: checkable,
    value: value,
    list: list,
    onChange: onChange
  }), /*#__PURE__*/React.createElement(List, {
    value: value,
    list: list,
    multiple: multiple,
    onBeforeChange: onBeforeChange,
    onChange: onChange
    // 选中效果: checkbox | tick | corner
    ,
    checkedType: checkedType
    // 选中位置: left | right
    ,
    checkedPosition: checkedPosition,
    checkable: checkable,
    itemProps: itemProps
  }), typeof listExtraFooterRender === 'function' && listExtraFooterRender({
    multiple: multiple,
    checkable: checkable,
    value: value,
    list: list,
    onChange: onChange
  })), FooterNode);
});
export default Main;
